@@ -1,4 +1,5 @@
 from tsdoc0.python.segment import Segment
+from tsdoc0.python.utils import repr_parent
 from typing import Final
 from typing import Optional
 from typing import TYPE_CHECKING
@@ -15,7 +16,7 @@ import attr
 class SolutionItem(Segment):
     # Forward reference used because there would be a circular dependency
     # https://mypy.readthedocs.io/en/latest/kinds_of_types.html#class-name-forward-references
-    parent: Optional["SolutionShape"] = attr.ib(eq=False)
+    parent: Optional["SolutionShape"] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
     key: Final[str]  # type: ignore[misc]
     value: Final[str]  # type: ignore[misc]
